# pyfilename

안전한 파일 이름을 제공하는 라이브러리입니다.

# 시작하기

1. 파이썬을 설치합니다.
2. cmd 창을 열어 pip 명령어를 실행합니다.
   ```
   pip install -U pyfilename
   ```

# 파일 이름 변환하기

다음과 같은 함수를 통해 파일 이름을 변환할 수 있습니다.

# Relese Note

0.1.0: 첫 릴리즈